twisted.protocols.policies.ProtocolWrapper

Package twisted :: Package protocols :: Module policies :: Class ProtocolWrapper |
[show private | hide private]
[frames | no frames]

## Class ProtocolWrapper

    BaseProtocol --+
                   |
            Protocol --+
                       |
                      ProtocolWrapper

Known Subclasses:
  `TLSTwistedProtocolWrapper`

Wraps protocol instances and acts as their transport as well.

Method Summary
| `__init__(self, factory, wrappedProtocol)`
| `__getattr__(self, name)`
| `connectionLost(self, reason)`
| ``connectionMade`(self)` Called when a connection is made.
| ``dataReceived`(self, data)` Called whenever data is received.
| `getHost(self)`
| `getPeer(self)`
| `loseConnection(self)`
| ``makeConnection`(self, transport)` Make a connection to a transport and a server.
| `registerProducer(self, producer, streaming)`
| `stopConsuming(self)`
| `unregisterProducer(self)`
| `write(self, data)`
| `writeSequence(self, data)`
Inherited from Protocol
| ``connectionFailed`(self)` (Deprecated)

Class Variable Summary
`tuple` | `__implements__` = `(<class 'twisted.internet.interfaces.IT...`
`int` | `disconnecting` = 0

Method Details

### connectionMade(self) Called when a connection is made. This may be considered the initializer of the protocol, because it is called when the connection is completed. For clients, this is called once the connection to the server has been established; for servers, this is called after an accept() call stops blocking and a socket has been received. If you need to send any greeting or initial message, do it here. Overrides: `twisted.internet.protocol.BaseProtocol.connectionMade` (inherited documentation)

### dataReceived(self, data) Called whenever data is received. Use this method to translate to a higher-level message. Usually, some callback will be made upon the receipt of each complete protocol message. Parameters: `data` - a string of indeterminate length. Please keep in mind that you will probably need to buffer some data, as partial (or multiple) protocol messages may be received! I recommend that unit tests for protocols call through to this method with differing chunk sizes, down to one byte at a time. Overrides: `twisted.internet.protocol.Protocol.dataReceived` (inherited documentation)

### makeConnection(self, transport) Make a connection to a transport and a server. This sets the 'transport' attribute of this Protocol, and calls the connectionMade() callback. Overrides: `twisted.internet.protocol.BaseProtocol.makeConnection` (inherited documentation)

Class Variable Details

    ### __implements__ Type: `tuple` Value:
        (<class 'twisted.internet.interfaces.ITransport'>,)

    ### disconnecting Type: `int` Value:
        0

Generated by Epydoc 2.0 on Mon Feb 21 21:56:54 2005 | http://epydoc.sf.net